# glam4cm

The data in this archive is derived from the user-contributed content on the
Cooking Stack Exchange website (https://cooking.stackexchange.com/), used under
CC-BY-SA 3.0 (http://creativecommons.org/licenses/by-sa/3.0/).

The original data dump can be downloaded from:
https://archive.org/download/stackexchange/cooking.stackexchange.com.7z
and details about the dump obtained from:
https://archive.org/details/stackexchange

We distribute two files, under CC-BY-SA 3.0:

 - cooking.stackexchange.txt, which contains all question titles and
   their associated tags (one question per line, tags are prefixed by
   the string "__label__") ;

 - cooking.stackexchange.id, which contains the corresponding row IDs,
   from the original data dump.


Node classification
  Language Model
    Freezing parameters
    Effect of attributes
    Effect of edge information
    Edge of partial node type information

  GNN
    GCNConv, SAGEConv, GATConv
    Random Node Embeddings
    Bert Node Embeddings
    Finetuned Node Embeddings
    Random Edge Embeddings
    Bert Edge Embeddings
    Finetuned Edge Embeddings